==> risk-center-api-0.2.0-20180627.023308-15-sources.jar: cn/com/duiba/tuia/risk/center/api/dto/req/ReqPageQuery.java <==
/**
 * 
 */
package cn.com.duiba.tuia.risk.center.api.dto.req;

import cn.com.duiba.tuia.risk.center.api.common.BaseDto;

import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;

/**
 * 此类描述的是： 分页查询条件.
 *
 * @author: cdm
 * @version: 2016年2月18日 上午9:48:22
 */
@ApiModel
public class ReqPageQuery extends BaseDto{


    /** 每页10条记录. */
    public static final int PAGE_SIZE_10    = 10;

    /** 每页20条记录. */
    public static final int PAGE_SIZE_20    = 20;

    /** 每页50条记录. */
    public static final int PAGE_SIZE_50    = 50;

    private static final long serialVersionUID = -9052866712359237685L;


    /** 起始记录数. */
    protected Integer         rowStart        = 0;

    /** 当前页. */
    @ApiModelProperty("当前页码")
    protected Integer         currentPage     = 1;

    /** 每页记录数， 为-1时代表查询所有. */
    @ApiModelProperty("每页条数")
    protected Integer         pageSize ;

    // todo startTime & endTime 写在这里有点不合适啊
    @ApiModelProperty("查询条件开始日期")
    protected String startTime;

    @ApiModelProperty("查询条件结束日期")
    protected String endTime;

    public void forExport() {
    	currentPage = 1;
    	pageSize = 10000;
	}


    public ReqPageQuery() {
        super();
        pageSize = PAGE_SIZE_10;
    }


    public Integer getRowStart() {
        return rowStart;
    }

    public void setRowStart(Integer rowStart) {
        this.rowStart = rowStart;
    }

    public Integer getCurrentPage() {
        return currentPage;
    }

    public void setCurrentPage(Integer currentPage) {
        this.currentPage = currentPage;
    }

    public Integer getPageSize() {
        return pageSize;
    }

    public void setPageSize(Integer pageSize) {
        this.pageSize = pageSize;
    }

    public String getStartTime() {
        return startTime;
    }

    public void setStartTime(String startTime) {
        this.startTime = startTime;
    }

    public String getEndTime() {
        return endTime;
    }

    public void setEndTime(String endTime) {
        this.endTime = endTime;
    }
}

==> risk-center-api-0.4.0-20180725.035223-3-sources.jar: cn/com/duiba/tuia/risk/center/api/dto/req/ReqPageQuery.java <==
/**
 * 
 */
package cn.com.duiba.tuia.risk.center.api.dto.req;

import cn.com.duiba.tuia.risk.center.api.common.BaseDto;

import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;

/**
 * 此类描述的是： 分页查询条件.
 *
 * @author: cdm
 * @version: 2016年2月18日 上午9:48:22
 */
@ApiModel
public class ReqPageQuery extends BaseDto{


    /** 每页10条记录. */
    public static final int PAGE_SIZE_10    = 10;

    /** 每页20条记录. */
    public static final int PAGE_SIZE_20    = 20;

    /** 每页50条记录. */
    public static final int PAGE_SIZE_50    = 50;

    private static final long serialVersionUID = -9052866712359237685L;


    /** 起始记录数. */
    @ApiModelProperty("2期后废弃")
    protected Integer         rowStart        = 0;

    /** 当前页. */
    @ApiModelProperty("当前页码")
    protected Integer         currentPage     = 1;

    /** 每页记录数， 为-1时代表查询所有. */
    @ApiModelProperty("每页条数")
    protected Integer         pageSize ;

    // todo startTime & endTime 写在这里有点不合适啊
    @ApiModelProperty("查询条件开始日期 2期后废弃")
    protected String startTime;

    @ApiModelProperty("查询条件结束日期 2期后废弃")
    protected String endTime;

    public void forExport() {
    	currentPage = 1;
    	pageSize = 10000;
	}


    public ReqPageQuery() {
        super();
        pageSize = PAGE_SIZE_10;
    }


    public Integer getRowStart() {
        return rowStart;
    }

    public void setRowStart(Integer rowStart) {
        this.rowStart = rowStart;
    }

    public Integer getCurrentPage() {
        return currentPage;
    }

    public void setCurrentPage(Integer currentPage) {
        this.currentPage = currentPage;
    }

    public Integer getPageSize() {
        return pageSize;
    }

    public void setPageSize(Integer pageSize) {
        this.pageSize = pageSize;
    }

    public String getStartTime() {
        return startTime;
    }

    public void setStartTime(String startTime) {
        this.startTime = startTime;
    }

    public String getEndTime() {
        return endTime;
    }

    public void setEndTime(String endTime) {
        this.endTime = endTime;
    }
}
